netapp_ontap.models.aggregate_warning API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_warning`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateWarningSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateWarning object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `action GET`

    The action field of the aggregate_warning.

  `name GET`

    Name of the entity that returns the warning.

  `warning GET`

    The warning field of the aggregate_warning.